@@ -1,8 +1,15 @@
-# $Id: Generator.pm,v 1.2 2001/08/06 09:59:13 matt Exp $
+# $Id: Generator.pm 603 2006-09-23 21:47:38Z pajas $
 
 package XML::LibXML::SAX::Generator;
 
+use strict;
+
 use XML::LibXML;
+use vars qw ($VERSION);
+
+$VERSION = "1.61"; # VERSION TEMPLATE: DO NOT CHANGE
+
+warn("This class (", __PACKAGE__, ") is deprecated!");
 
 sub new {
     my $class = shift;
@@ -124,6 +131,8 @@ XML::LibXML::SAX::Generator - Generate SAX events from a LibXML tree
 
 =head1 DESCRIPTION
 
+THIS CLASS IS DEPRACED! Use XML::LibXML::SAX::Parser instead!
+
 This helper class allows you to generate SAX events from any XML::LibXML
 node, and all it's sub-nodes. This basically gives you interop from
 XML::LibXML to other modules that may implement SAX.
